mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Philipp Hortmann <philipp.g.hortmann@gmail.com>
To: Forest Bond <forest@alittletooquiet.net>,
	Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
	linux-staging@lists.linux.dev, linux-kernel@vger.kernel.org
Subject: [PATCH 02/12] staging: vt6655: Cleanup and rename function MACvSaveContext
Date: Sun, 11 Sep 2022 12:45:42 +0200	[thread overview]
Message-ID: <f514711695f1eafde9996edcc246da2adcd5f9c5.1662890990.git.philipp.g.hortmann@gmail.com> (raw)
In-Reply-To: <cover.1662890990.git.philipp.g.hortmann@gmail.com>

Rename function MACvSaveContext to vt6655_mac_save_context to avoid
CamelCase which is not accepted by checkpatch.pl. Remove unnecessary
declaration of function and make function static. Change declaration of
cxt_buf to shorten code.

Signed-off-by: Philipp Hortmann <philipp.g.hortmann@gmail.com>
---
 drivers/staging/vt6655/mac.c | 6 +++---
 drivers/staging/vt6655/mac.h | 1 -
 2 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/drivers/staging/vt6655/mac.h b/drivers/staging/vt6655/mac.h
index f7d00a251677..1752905d7df0 100644
--- a/drivers/staging/vt6655/mac.h
+++ b/drivers/staging/vt6655/mac.h
@@ -553,7 +553,6 @@ void vt6655_mac_set_short_retry_limit(struct vnt_private *priv, unsigned char re
 
 void MACvSetLongRetryLimit(struct vnt_private *priv, unsigned char byRetryLimit);
 
-void MACvSaveContext(struct vnt_private *priv, unsigned char *cxt_buf);
 void MACvRestoreContext(struct vnt_private *priv, unsigned char *cxt_buf);
 
 bool MACbSoftwareReset(struct vnt_private *priv);
diff --git a/drivers/staging/vt6655/mac.c b/drivers/staging/vt6655/mac.c
index 567bc38ecfa9..092b1fffcfa1 100644
--- a/drivers/staging/vt6655/mac.c
+++ b/drivers/staging/vt6655/mac.c
@@ -14,7 +14,7 @@
  *      vt6655_mac_set_short_retry_limit - Set 802.11 Short Retry limit
  *      MACvSetLongRetryLimit - Set 802.11 Long Retry limit
  *      vt6655_mac_set_loopback_mode - Set MAC Loopback Mode
  *      MACvSaveContext - Save Context of MAC Registers
  *      MACvRestoreContext - Restore Context of MAC Registers
  *      MACbSoftwareReset - Software Reset MAC
  *      MACbSafeRxOff - Turn Off MAC Rx
@@ -181,7 +181,7 @@ static void vt6655_mac_set_loopback_mode(struct vnt_private *priv, u8 loopback_m
  * Return Value: none
  *
  */
-void MACvSaveContext(struct vnt_private *priv, unsigned char *cxt_buf)
+static void vt6655_mac_save_context(struct vnt_private *priv, u8 *cxt_buf)
 {
 	void __iomem *io_base = priv->port_offset;
 
@@ -303,7 +303,7 @@ bool MACbSafeSoftwareReset(struct vnt_private *priv)
 	 * reset, then restore register's value
 	 */
 	/* save MAC context */
-	MACvSaveContext(priv, abyTmpRegData);
+	vt6655_mac_save_context(priv, abyTmpRegData);
 	/* do reset */
 	bRetVal = MACbSoftwareReset(priv);
 	/* restore MAC context, except CR0 */
@@ -14,7 +14,7 @@
  *      MACvSetLongRetryLimit - Set 802.11 Long Retry limit
  *      vt6655_mac_set_loopback_mode - Set MAC Loopback Mode
- *      MACvSaveContext - Save Context of MAC Registers
+ *      vt6655_mac_save_context - Save Context of MAC Registers
  *      MACvRestoreContext - Restore Context of MAC Registers
  *      MACbSoftwareReset - Software Reset MAC
-- 
2.37.3


  parent reply	other threads:[~2022-09-11 10:46 UTC|newest]

Thread overview: 16+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-09-11 10:45 [PATCH 00/12] staging: vt6655: Cleanup and rename functions of mac.h Philipp Hortmann
2022-09-11 10:45 ` [PATCH 01/12] staging: vt6655: Cleanup and rename function MACvSetLoopbackMode Philipp Hortmann
2022-09-11 10:45 ` Philipp Hortmann [this message]
2022-09-11 10:45 ` [PATCH 03/12] staging: vt6655: Cleanup and rename function MACvRestoreContext Philipp Hortmann
2022-09-11 10:46 ` [PATCH 04/12] staging: vt6655: Cleanup and rename function MACbSafeSoftwareReset Philipp Hortmann
2022-09-13 10:12   ` Dan Carpenter
2022-09-13 18:26     ` Philipp Hortmann
2022-09-14 14:47       ` Dan Carpenter
2022-09-11 10:46 ` [PATCH 05/12] staging: vt6655: Rename function MACbSafeRxOff Philipp Hortmann
2022-09-11 10:46 ` [PATCH 06/12] staging: vt6655: Rename function MACbSafeTxOff Philipp Hortmann
2022-09-11 10:46 ` [PATCH 07/12] staging: vt6655: Rename function MACbSafeStop Philipp Hortmann
2022-09-11 10:46 ` [PATCH 08/12] staging: vt6655: Rename function MACvSetCurrRx0DescAddr Philipp Hortmann
2022-09-11 10:47 ` [PATCH 09/12] staging: vt6655: Rename function MACvSetCurrRx1DescAddr Philipp Hortmann
2022-09-11 10:47 ` [PATCH 10/12] staging: vt6655: Cleanup and rename function MACvSetCurrTXDescAddr Philipp Hortmann
2022-09-11 10:47 ` [PATCH 11/12] staging: vt6655: Rename function MACvSetCurrTx0DescAddrEx Philipp Hortmann
2022-09-11 10:47 ` [PATCH 12/12] staging: vt6655: Rename function MACvSetCurrAC0DescAddrEx Philipp Hortmann

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=f514711695f1eafde9996edcc246da2adcd5f9c5.1662890990.git.philipp.g.hortmann@gmail.com \
    --to=philipp.g.hortmann@gmail.com \
    --cc=forest@alittletooquiet.net \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-staging@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®